Learn R Programming

havel (version 0.1.2)

havel-package: A short title line describing what the package does

Description

A more detailed description of what the package does. A length of about one to five lines is recommended.

Arguments

Author

Your Name, email optional.

Maintainer: Your Name <your@email.com>

Details

This section should provide a more detailed overview of how to use the package, including the most important functions.