pkg_depsThis is a named list containing pre-computed examples of package dependency
information for packages data.table (v1.17.8), ggplot2
(v4.0.1), and utils pulled on Monday November 15th 2025. The first two
use pkg_deps from the pak package and the
last one uses an internal function in havel that falls back to
package_dependencies from
tools (pkg_deps fails on base packages).
These precomputed results are used to provide data to run the examples
without requiring internet access (notably on CRAN's servers).
pkg_deps_exA named list containing three data frames of package dependency information:
a tibble describing data.table's dependencies
a tibble describing ggplot2's dependencies
a data.table describing utils's dependencies